extract_gene_names: Creates a ordered list of colnames of a given Matrix

Description Usage Arguments Value Examples

View source: R/extract_gene_names.R

Description

This function orders the columns of a matrix by variance starting with the highest within column variance left to the lowest within column variance on the right.

Usage

1

Arguments

matrix

a numerical matrix

Value

vector containing colnames

Examples

1
2
3
4
5
## Not run: 
colnames <- matrix %>%
  extract_gene_names()

## End(Not run)

ECSchmitt/PPClustA documentation built on Dec. 17, 2021, 5:36 p.m.