load_expr_data: Creates gene expression matrix from the Golub data

Description Usage Value Examples

View source: R/load_expr_data.R

Description

Calling this function will load the 'golubEsets' and 'tidyverse' libraries. Furthermore, the Golub_Train matrix with gene espression data will be loaded and transposed. After transposing it, zeros will be replaced by ones and the expression values are normalised by applying log2. Afterwards, rownames of the expression matrix are changed from patient IDs to the corresponding cancertypes.

Usage

1

Value

normalized expression matrix of Golub data

Examples

1
2
3
4
5
6
7
## Not run: 
library("Golub_Train")
data("Golub_Train")
expression_Matrix <- Golub_Train
return(expression_Matrix)

## End(Not run)

ECSchmitt/PPClustA documentation built on Dec. 17, 2021, 5:36 p.m.