replace_zeros: Replaces zeros in a numerical matrix

Description Usage Arguments Examples

View source: R/replace_zeros.R

Description

Replaces zeros in a numerical matrix with a given numerical value x. Was written to enable the matrix operator to be used within a dplyr pipe

Usage

1

Arguments

matrix

numerical matrix

x

numerical value to replace zeros with

Examples

1
2
3
4
5
## Not run: 
matrix %>%
  replace_zeros(x)

## End(Not run)

ECSchmitt/PPClustA documentation built on Dec. 17, 2021, 5:36 p.m.