Description Usage Value Examples
View source: R/load_expr_data.R
Calling this function will load the 'golubEsets' and 'tidyverse' libraries. Furthermore, the Golub_Train matrix with gene espression data will be loaded and transposed. After transposing it, zeros will be replaced by ones and the expression values are normalised by applying log2. Afterwards, rownames of the expression matrix are changed from patient IDs to the corresponding cancertypes.
1 |
normalized expression matrix of Golub data
1 2 3 4 5 6 7 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.