Description Usage Arguments Examples
View source: R/replace_zeros.R
Replaces zeros in a numerical matrix with a given numerical value x. Was written to enable the matrix operator to be used within a dplyr pipe
1 | replace_zeros(matrix, x)
|
matrix |
numerical matrix |
x |
numerical value to replace zeros with |
1 2 3 4 5 | ## Not run:
matrix %>%
replace_zeros(x)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.